@@ -99,7 +99,7 @@ def putInCsv(Topic_Number,Number_Of_Iterations,Main_Function,Filename,Remove_Dup
     if(os.path.exists(csv_filename)):
         m = 'a+'
 
-    with open(csv_filename,mode=m,newline='') as f:
+    with open(csv_filename,mode=m,newline='',encoding='utf-8') as f:
         fieldnames = [
             'Question_Type',
             'Answer_Type',
